var prefService = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefService);
var prefBranch = prefService.getBranch("tvmoz."); 

/*
	available boolean preferences for tvmoz:
	tvmoz.gif
	tvmoz.jpg
	tvmoz.png
	tvmoz.html
	tvmoz.txt
	tvmoz.multipleTab
	tvmoz.singleTab
*/

//reads string preference from prefs.js
//if an error is thrown, then it assigns it a default value
function readCharPreference(key, defaultValue) 
{
   var value;
   try 
   {
     value = prefBranch.getCharPref(key);
   } 
   catch(err) 
   {
     alert("ERROR: isReadPref(): " + err.description);
     value = defaultValue; 
   }
   return value;
}

//writes a char preference to prefs.js
function writeCharPreference(key, value) 
{
   //alert("writing preference: " + key + " value: " + value);
   try 
   {
     prefBranch.setCharPref(key, value);
   } 
   catch (err) 
   {   
     alert("\nError while saving preferences for " + key + ":" + value + " - " + err.description + "\n");
   }
   try 
   {
	prefService.savePrefFile(null);
   }
   catch (err) 
   {
        alert("\nError while saving preferences: " + err + "\n");
   }
}


//reads boolean preference from prefs.js
//if an error is thrown, then it assigns it a default value
function readPreference(key, defaultValue) 
{
   var value;
   try 
   {
     value = prefBranch.getBoolPref(key);
   } 
   catch(err) 
   {
     alert("ERROR: isReadPref(): " + err.description);
     value = defaultValue; 
   }
   return value;
}

//writes a preference to prefs.js
function writePreference(key, value) 
{
   //alert("writing preference: " + key + " value: " + value);
   try 
   {
     prefBranch.setBoolPref(key, value);
   } 
   catch (err) 
   {   
     alert("\nError while saving preferences for " + key + ":" + value + " - " + err.description + "\n");
   }
   try 
   {
	prefService.savePrefFile(null);
   }
   catch (err) 
   {
        alert("\nError while saving preferences: " + err + "\n");
   }
}

//populates preferences GUI based on current preference statuses
function populatePreferences()
{	
	try
	{
		//alert("populating preferences");
		
		var gif = readPreference("gif",true);		
		if(gif == true)
		{
			document.getElementById("chkGif").checked = true;
		}
		else	
		{
			document.getElementById("chkGif").checked = false;
		}
		
		var jpg = readPreference("jpg",true);		
		if(jpg == true)
		{
			document.getElementById("chkJpg").checked = true;
		}
		else	
		{
			document.getElementById("chkJpg").checked = false;
		}
		
		var png = readPreference("png",true);		
		if(png == true)
		{
			document.getElementById("chkPng").checked = true;
		}
		else	
		{
			document.getElementById("chkPng").checked = false;
		}
			
		var html = readPreference("html",false);		
		if(html == true)
		{
			document.getElementById("chkHtml").checked = true;
		}
		else	
		{
			document.getElementById("chkHtml").checked = false;
		}
		
		var txt = readPreference("txt",false);		
		if(txt == true)
		{
			document.getElementById("chkTxt").checked = true;
		}
		else	
		{
			document.getElementById("chkTxt").checked = false;
		}
		
		
		
		var singleTab = readPreference("singleTab",true);		
		if(singleTab == true)
		{
			
			document.getElementById("tabs").selectedIndex = 0;
		}
		else	
		{
			document.getElementById("tabs").selectedIndex = 1;
		}
		
		var multipleTab = readPreference("multipleTab",false);		
		if(multipleTab == true)
		{
			document.getElementById("tabs").selectedIndex = 1;
		}
		else	
		{
			document.getElementById("tabs").selectedIndex = 0;
		}
			
			
		var savedPath = readCharPreference("savedPath", "NOT_DEFINED");
			document.getElementById("txtSaveLocation").value = savedPath;		
		
	}
	catch(err)
	{
		alert("Error populating preferences: " + err);
	}
}	

//saves preferences based on user changes
//implemented method because couldn't figure out how to save preferences directly using the preference tags. After 2 days it's time to try alternatives i think :)
function savePreferences()
{		
	var pGIF = document.getElementById("chkGif").checked ? true : false;
	var pJPG = document.getElementById("chkJpg").checked ? true : false;
	var pPNG = document.getElementById("chkPng").checked ? true : false;
	var pHTML = document.getElementById("chkHtml").checked ? true : false;
	var pTEXT = document.getElementById("chkTxt").checked ? true : false;
	
	var pSINGLETAB = document.getElementById("sTab").selected ? true : false;
	//alert("pSINGLETAB: " + pSINGLETAB);
	var pMULTITAB = document.getElementById("mTab").selected ? true : false;
	//alert("pMULTITAB: " + pMULTITAB);
	
		
	writePreference("gif",pGIF);
	writePreference("jpg",pJPG);
	writePreference("png",pPNG);
	writePreference("html",pHTML);
	writePreference("txt",pTEXT);
	writePreference("singleTab",pSINGLETAB);
	writePreference("multipleTab",pMULTITAB);
	writeCharPreference("savedPath",document.getElementById("txtSaveLocation").value);
	alert("Your Preferences Were Saved!");
}

//test for setting preferences
function testPreferences()
{
	alert("Testing Preferences");
	writePreference("vlad",true);
	writePreference("gif",true);
	writePreference("jpg",false);
	writePreference("png",true);
	writePreference("html",true);
	writePreference("txt",false);
	writePreference("singleTab",true);
	writePreference("multipleTab",false);
	var pref = readPreference("vlad",false);
	alert("pref=" + pref);
}